| Title: | Conservation Planning Datasets |
|---|---|
| Description: | Conservation planning datasets for learning how to use the 'prioritizr' package <https://CRAN.R-project.org/package=prioritizr>. |
| Authors: | Jeffrey O Hanson [aut] (ORCID: <https://orcid.org/0000-0002-4716-6134>), Richard Schuster [aut, cre] (ORCID: <https://orcid.org/0000-0003-3191-7869>), Nina Morrell [aut], Matthew Strimas-Mackey [aut] (ORCID: <https://orcid.org/0000-0001-8929-7776>), Kristine Camille V Buenafe [aut] (ORCID: <https://orcid.org/0000-0002-1643-5557>), Matthew E Watts [aut], Peter Arcese [aut] (ORCID: <https://orcid.org/0000-0002-8097-482X>), Joseph R Bennett [aut] (ORCID: <https://orcid.org/0000-0002-3901-9513>), Hugh P Possingham [aut] (ORCID: <https://orcid.org/0000-0001-7755-996X>) |
| Maintainer: | Richard Schuster <[email protected]> |
| License: | GPL-3 |
| Version: | 0.3.3 |
| Built: | 2026-06-11 18:23:04 UTC |
| Source: | https://github.com/cran/prioritizrdata |
The prioritizrdata package is a supplemental package that contains example datasets for conservation planning. It is intended to be used alongside the prioritizr package.
This package contains the following datasets:
Conservation planning dataset for Tasmania, Australia.
Conservation planning dataset for Salt Spring Island, Canada.
Conservation planning dataset for Washington, United States.
Maintainer: Richard Schuster [email protected] (ORCID)
Authors:
Richard Schuster [email protected] (ORCID)
Jeffrey O Hanson [email protected] (ORCID)
Nina Morrell [email protected]
Matthew Strimas-Mackey [email protected] (ORCID)
Kristine Camille V Buenafe [email protected] (ORCID)
Matthew E Watts [email protected]
Peter Arcese [email protected] (ORCID)
Joseph R Bennett [email protected] (ORCID)
Hugh P Possingham [email protected] (ORCID)
Useful links:
Report bugs at https://github.com/prioritizr/prioritizrdata/issues
The functions listed here are deprecated. This means that they once existed in earlier versions of the of the prioritizrdata package, but they have since been removed entirely, replaced by other functions, or renamed as other functions in newer versions. To help make it easier to transition to new versions of the prioritizrdata package, we have listed alternatives for deprecated the functions (where applicable). If a function is described as being renamed, then this means that only the name of the function has changed (i.e., the inputs, outputs, and underlying code remain the same).
get_wa_features()get_wa_features()
The following functions have been deprecated:
get_wa_features()renamed as the get_wa_species() function.
Conservation planning dataset for Salt Spring Island, Canada. It was obtained as part of an online Marxan-based planning tool created for the Coastal Douglas-fir Conservation Partnership (CDFCP; Schuster et al. 2017).
get_salt_pu() get_salt_features() get_salt_con()get_salt_pu() get_salt_features() get_salt_con()
terra::rast() object.
terra::rast() object.
terra::rast() object.
The following functions are provided to import data:
get_salt_pu()Import planning unit data.
The planning units are a single layer terra::rast() object.
Cell values denote the monetary cost of acquiring different areas
(e.g., a value of 1 = $100,000 CAD; BC Land Assessment
2015).
get_salt_features()Import biodiversity feature data.
The feature data are a multi-layer
terra::rast() object object.
It contains the spatial distribution of four key ecological communities.
Each layer represents a different community type.
These classes are (i) old forest, (ii) savanna, (iii) wetland,
and (iv) shrub. For each layer, values indicate the
composite probability of encountering the suite of bird species most
commonly associated with that community type.
get_salt_con()Import connectivity data.
The connectivity data are a single-layer
terra::rast() object.
It contains the inverse probability of occurrence of human
commensal species.
Based on the assumption that human modified areas
impede connectivity for native fauna, cells with higher values
have higher connectivity.
BC Assessment (2015) Property Information Services. Available at https://www.bcassessment.ca/ (Date Accessed 2016/06/13).
Morrell N, Schuster R, Crombie M, and Arcese P (2017) A Prioritization Tool for the Conservation of Coastal Douglas-fir Forest and Savannah Habitats of the Georgia Basin. The Nature Trust of British Colombia, Coastal Douglas Fir Conservation Partnership, and the Department of Forest and Conservation Sciences, University of British Colombia. Available at https://peter-arcese-lab.sites.olt.ubc.ca/files/2016/09/CDFCP_tutorial_2017_05.pdf (Date Accessed 2017/10/09).
# load packages library(terra) library(sf) # import data salt_pu <- get_salt_pu() salt_features <- get_salt_features() # preview planning units print(salt_pu) plot(salt_pu) # preview features print(salt_features) plot(salt_features) # preview connectivity data salt_con <- get_salt_con() print(salt_con) plot(salt_con)# load packages library(terra) library(sf) # import data salt_pu <- get_salt_pu() salt_features <- get_salt_features() # preview planning units print(salt_pu) plot(salt_pu) # preview features print(salt_features) plot(salt_features) # preview connectivity data salt_con <- get_salt_con() print(salt_con) plot(salt_con)
Conservation planning dataset for Tasmania, Australia.
get_tas_pu() get_tas_features()get_tas_pu() get_tas_features()
sf::st_sf() object.
terra::rast() object
The following functions are provided to import data:
get_tas_puImport planning unit data.
The planing units are a sf::st_sf() simple features object.
Each row corresponds to a different planning unit, and columns
contain information about the planning units.
It has columns that contain: ("id") unique identifiers and
("cost") unimproved land values for the planning units.
It also contains columns ("locked_in" and "locked_out")
with logical values (i.e. TRUE or FALSE values)
for locking in and locking out planning units.
These data obtained from the
"Introduction to Marxan" course
and were originally generated as part of a larger spatial prioritization
Resources (Klein et al. 2007).
get_tas_featuresImport biodiversity feature data.
The feature data are a multi-layer terra::rast() object.
classes. Each layer corresponds to a
different vegetation class and contains binary cell values that indicate
the presence or absence of the vegetation class.
These data were obtained from the Australian Government's National
Vegetation Information System (Australian Government Department of Climate
Change, Energy, the Environment and Water 2020).
Klein C, Carwardine J, Wilson K, Watts M, and Possingham H (2007) Spatial Prioritization Approaches for the Conservation of Biodiversity in Australia: Considering Conservation Costs, Ecological & Evolutionary Processes, and Large-Intact Areas. Report to the Department of Environment; Water Resources.
Australian Government Department of Climate Change, Energy, the Environment and Water (2020). National Vegetation Information System. Version 6.0. Available at https://digital.atlas.gov.au/maps/national-vegetation-information-system-nvis-version-6-0-extant-vegetation.
# load packages library(terra) library(sf) # load data tas_pu <- get_tas_pu() tas_features <- get_tas_features() # preview planning units print(tas_pu) plot(tas_pu) # plot features print(tas_features) plot(tas_features)# load packages library(terra) library(sf) # load data tas_pu <- get_tas_pu() tas_features <- get_tas_features() # preview planning units print(tas_pu) plot(tas_pu) # plot features print(tas_features) plot(tas_features)
Conservation planning dataset for Washington, The United States of America.
get_wa_pu() get_wa_locked_in() get_wa_locked_out() get_wa_species() get_wa_attr() get_wa_carbon()get_wa_pu() get_wa_locked_in() get_wa_locked_out() get_wa_species() get_wa_attr() get_wa_carbon()
terra::rast() object.
terra::rast() object.
terra::rast() object.
terra::rast() object.
terra::rast() object.
tibble::tibble() object.
The following functions are provided to import data:
get_wa_pu()Import planning unit data.
The planning units are a single layer terra::rast() object.
Cell values denote land acquisition costs.
These data were originally obtained from Nolte (2020 a,b).
get_wa_locked_in()Import locked in data.
The locked in data are a single layer terra::rast() object.
Cell values denote binary values indicating if each cell
is predominantly covered by protected areas
(excluding those with no mandate for biodiversity protection).
These data were originally obtained from USGS (2022)
get_wa_locked_in()Import locked out data.
The locked out data are a single layer terra::rast() object.
Cell values denote binary values indicating if each cell
is predominantly covered by urban areas.
These data were originally obtained from the
Commission for Environmental Cooperation (2020)
get_wa_carbon()Import vulnerable carbon data.
The carbon data a single layer terra::rast() object.
Cell values denote continuous values representing the amount
of carbon sequestered that is vulnerable to be released through
typical land-use conversion.
These data were originally obtained from the
Noon et al. (2021, 2022)
get_wa_species()Import species distribution data.
The feature data are a multi-layer
terra::rast() object.
It contains the spatial distribution of 258 bird species.
To account for migratory patterns, data are provided for the
breeding and non-breeding distributions of species
(indicated by "breeding" and "non-breeding" in the layer names).
If a species is lacking such information,
then the species is denoted with its full distribution
(as indicated "full" in the layer names).
These data were originally obtained from the eBird Status and Trends
dataset (Fink et al. 2020). To ensure backwards compatibility
with previous versions of the package, get_wa_features() can
also be used to access these data.
get_wa_attr()Import attribute data about the species.
The feature attribute data are a data frame (tibble::tibble()) object.
It contains taxonomic information for each feature
(i.e., layer in get_wa_species()) as well as estimates of
public interest (derived from Mittermeier et al. 2021) and
extinction risk (based on the methodology of Davis et al. 2018 and
and threat status classification data from IUCN 2025).
Since Mittermeier et al. (2021)
did not contain public interest scores for all features,
scores were interpolated for features missing scores based on average
public interest score of features that belong to the same
taxonomic family. This object has the following columns:
Name of the feature (i.e., per get_wa_species()).
Taxonomic species and genus name of the feature.
Taxonomic family name of the feature.
Taxonomic order of the feature.
Probability of extinction.
Public interest score.
Commission for Environmental Cooperation. (2020). 2015 Land Cover of North America at 30 Meters. North American Land Change Monitoring System, 2nd Edition, https://www.cec.org:443/north-american-environmental-atlas/land-cover-30m-2015-landsat-and-rapideye/.
Davis M, Faurby S, and Svenning J-C (2018) Mammal diversity will take millions of years to recover from the current biodiversity crisis. Proceedings of the National Academy of Sciences, 115: 11262–11267.
Fink D, Auer T, Johnston A, Ruiz-Gutierrez V, Hochachka WM and Kelling S (2020) Modeling avian full annual cycle distribution and population trends with citizen science data. Ecological Applications, 30: e02056.
IUCN (2025) The IUCN Red List of Threatened Species. Version 2025-2. https://www.iucnredlist.org. Accessed on 13 May 2026.
Mittermeier JC, Roll U, Matthews TJ, Correia R, and Grenyer R (2021) Birds that are more commonly encountered in the wild attract higher public interest online. Conservation Science and Practice, 3: e340.
Nolte C (2020a) Data for: High-resolution land value maps reveal underestimation of conservation costs in the United States. Dryad, Dataset, doi:10.5061/dryad.np5hqbzq9.
Nolte C (2020b) High-resolution land value maps reveal underestimation of conservation costs in the United States. Proceedings of the National Academy of Sciences, 117: 29577–29583.
Noon ML, Goldstein A, Ledezma JC, Roehrdanz PR, Cook-Patton SC, Spawn-Lee SA, Wright TM, Gonzalez-Roglich M, Hole DG, Rockström J, and Turner WR (2022) Mapping the irrecoverable carbon in Earth's ecosystems. Nature Sustainability, 5: 37–46.
Noon ML, Goldstein A, Ledezma JC, Roehrdanz PR, Cook-Patton SC, Spawn-Lee SA, Wright TM, Gonzalez-Roglich M, Hole DG, Rockström J, and Turner WR (2021) Mapping the irrecoverable carbon in Earth's ecosystems (2.0) [Data set]. Zenodo. doi:10.5281/zenodo.4091029.
U.S. Geological Survey (USGS) Gap Analysis Project (GAP) (2022) Protected Areas Database of the United States (PAD-US) 3.0: U.S. Geological Survey data release, doi:10.5066/P9Q9LQ4B.
# load packages library(terra) # import data wa_pu <- get_wa_pu() wa_species <- get_wa_species() wa_attr <- get_wa_attr() wa_locked_in <- get_wa_locked_in() wa_locked_out <- get_wa_locked_out() wa_carbon <- get_wa_carbon() # preview planning units print(wa_pu) plot(wa_pu) # preview locked in print(wa_locked_in) plot(wa_locked_in) # preview locked out print(wa_locked_out) plot(wa_locked_out) # preview species print(wa_species) plot(wa_species) # preview attributes of species print(wa_attr)# load packages library(terra) # import data wa_pu <- get_wa_pu() wa_species <- get_wa_species() wa_attr <- get_wa_attr() wa_locked_in <- get_wa_locked_in() wa_locked_out <- get_wa_locked_out() wa_carbon <- get_wa_carbon() # preview planning units print(wa_pu) plot(wa_pu) # preview locked in print(wa_locked_in) plot(wa_locked_in) # preview locked out print(wa_locked_out) plot(wa_locked_out) # preview species print(wa_species) plot(wa_species) # preview attributes of species print(wa_attr)